==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/uk/servicediscovery.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>DiscoInfoWindow</name>
    <message>
        <source>Error %1: %2</source>
        <translation>Помилка %1: %2</translation>
    </message>
    <message>
        <source>Discovery Info - %1</source>
        <translation>Оглядова інформація - %1</translation>
    </message>
</context>
<context>
    <name>DiscoInfoWindowClass</name>
    <message>
        <source>Identities:</source>
        <translation>Елементи:</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Категорія</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <source>Features:</source>
        <translation>Можливості:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Опис:</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Поновити</translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation>Розширення</translation>
    </message>
</context>
<context>
    <name>DiscoItemsModel</name>
    <message>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <source>Jid</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Вузол</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Identity:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Елемент:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;%1 (Category: &apos;%2&apos;; Type: &apos;%3&apos;)&lt;/li&gt;</source>
        <translation>&lt;li&gt;%1 (Категорія: &apos;%2&apos;; Тип: &apos;%3&apos;)&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Features:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Можливості:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>true</source>
        <translation>Так</translation>
    </message>
    <message>
        <source>false</source>
        <translation>Ні</translation>
    </message>
    <message>
        <source>Error %1: %2</source>
        <translation>Помилка %1: %2</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindow</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперед</translation>
    </message>
    <message>
        <source>Discover</source>
        <translation>Огляд</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Поновити</translation>
    </message>
    <message>
        <source>Disco info</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Add Contact</source>
        <translation>Додати контакт</translation>
    </message>
    <message>
        <source>vCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Service Discovery - %1</source>
        <translation>Огляд сервісів - %1</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindowClass</name>
    <message>
        <source>Node:</source>
        <translation>Вузол:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Дії</translation>
    </message>
    <message>
        <source>Item:</source>
        <translation>Елемент:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Пошук:</translation>
    </message>
</context>
<context>
    <name>ServiceDiscovery</name>
    <message>
        <source>Service Discovery</source>
        <translation>Огляд сервісів</translation>
    </message>
    <message>
        <source>JID Escaping</source>
        <translation>Екранування JID</translation>
    </message>
    <message>
        <source>Discovery Info</source>
        <translation>Оглядова інформація</translation>
    </message>
    <message>
        <source>Entity Capabilities</source>
        <translation>Можливості об&apos;єкту</translation>
    </message>
    <message>
        <source>Allows to receive information about Jabber entities</source>
        <translation>Дозволяє отримувати інформацію про джаббер сутності</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information and items</source>
        <translation>Підтримує обмін оглядовою інформацією та елементами</translation>
    </message>
    <message>
        <source>Discovery Information</source>
        <translation>Оглядова інформація</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information</source>
        <translation>Підтримує обмін оглядовою інформацією</translation>
    </message>
    <message>
        <source>Discovery Items</source>
        <translation>Оглядові елементи</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery items</source>
        <translation>Підтримує обмін оглядовими елементами</translation>
    </message>
    <message>
        <source>Publish Items</source>
        <translation>Публікація елементів</translation>
    </message>
    <message>
        <source>Supports the publishing of the discovery items</source>
        <translation>Підтримує публікацію оглядових елементів</translation>
    </message>
    <message>
        <source>Supports the caching of the discovery information</source>
        <translation>Підтримує кешування оглядової інформації</translation>
    </message>
    <message>
        <source>Supports the displaying of the jabber identifiers with disallowed characters</source>
        <translation>Підтримує перегляд джаббер ідентифікаторів з забороненими символами</translation>
    </message>
    <message>
        <source>Service discovery window</source>
        <translation>Вікно огляду сервісів</translation>
    </message>
    <message>
        <source>Move back</source>
        <translation>Піти назад</translation>
    </message>
    <message>
        <source>Move forward</source>
        <translation>Піти вперед</translation>
    </message>
    <message>
        <source>Discover item</source>
        <translation>Переглянути </translation>
    </message>
    <message>
        <source>Reload items</source>
        <translation>Перезавантажити </translation>
    </message>
    <message>
        <source>Show discovery info</source>
        <translation>Показати оглядову інформацію </translation>
    </message>
    <message>
        <source>Add item to roster</source>
        <translation>Додати до ростеру</translation>
    </message>
    <message>
        <source>Show vCard</source>
        <translation>Показати візитівку</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <comment>Show vCard</comment>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Close discovery window</source>
        <translation>Закрити вікно оглядової інформації</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close discovery window</comment>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Category: %1; Type: %2</source>
        <translation>Категорія: %1; Тип: %2</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/uk/servicediscovery.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>DiscoInfoWindow</name>
    <message>
        <source>Discovery Info - %1</source>
        <translation>Оглядова інформація - %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Помилка: %1</translation>
    </message>
</context>
<context>
    <name>DiscoInfoWindowClass</name>
    <message>
        <source>Identities:</source>
        <translation>Елементи:</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Категорія</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <source>Features:</source>
        <translation>Можливості:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Опис:</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Поновити</translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation>Розширення</translation>
    </message>
</context>
<context>
    <name>DiscoItemsModel</name>
    <message>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <source>Jid</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Вузол</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Identity:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Елемент:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;%1 (Category: &apos;%2&apos;; Type: &apos;%3&apos;)&lt;/li&gt;</source>
        <translation>&lt;li&gt;%1 (Категорія: &apos;%2&apos;; Тип: &apos;%3&apos;)&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Features:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Можливості:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>true</source>
        <translation>Так</translation>
    </message>
    <message>
        <source>false</source>
        <translation>Ні</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Помилка: %1</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindow</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперед</translation>
    </message>
    <message>
        <source>Discover</source>
        <translation>Огляд</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Поновити</translation>
    </message>
    <message>
        <source>Disco info</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Add Contact</source>
        <translation>Додати контакт</translation>
    </message>
    <message>
        <source>vCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Service Discovery - %1</source>
        <translation>Огляд сервісів - %1</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindowClass</name>
    <message>
        <source>Node:</source>
        <translation>Вузол:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Дії</translation>
    </message>
    <message>
        <source>Item:</source>
        <translation>Елемент:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Пошук:</translation>
    </message>
</context>
<context>
    <name>ServiceDiscovery</name>
    <message>
        <source>Service Discovery</source>
        <translation>Огляд сервісів</translation>
    </message>
    <message>
        <source>JID Escaping</source>
        <translation>Екранування JID</translation>
    </message>
    <message>
        <source>Discovery Info</source>
        <translation>Оглядова інформація</translation>
    </message>
    <message>
        <source>Entity Capabilities</source>
        <translation>Можливості об&apos;єкту</translation>
    </message>
    <message>
        <source>Allows to receive information about Jabber entities</source>
        <translation>Дозволяє отримувати інформацію про джаббер сутності</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information and items</source>
        <translation>Підтримує обмін оглядовою інформацією та елементами</translation>
    </message>
    <message>
        <source>Discovery Information</source>
        <translation>Оглядова інформація</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information</source>
        <translation>Підтримує обмін оглядовою інформацією</translation>
    </message>
    <message>
        <source>Discovery Items</source>
        <translation>Оглядові елементи</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery items</source>
        <translation>Підтримує обмін оглядовими елементами</translation>
    </message>
    <message>
        <source>Publish Items</source>
        <translation>Публікація елементів</translation>
    </message>
    <message>
        <source>Supports the publishing of the discovery items</source>
        <translation>Підтримує публікацію оглядових елементів</translation>
    </message>
    <message>
        <source>Supports the caching of the discovery information</source>
        <translation>Підтримує кешування оглядової інформації</translation>
    </message>
    <message>
        <source>Supports the displaying of the jabber identifiers with disallowed characters</source>
        <translation>Підтримує перегляд джаббер ідентифікаторів з забороненими символами</translation>
    </message>
    <message>
        <source>Service discovery window</source>
        <translation>Вікно огляду сервісів</translation>
    </message>
    <message>
        <source>Move back</source>
        <translation>Піти назад</translation>
    </message>
    <message>
        <source>Move forward</source>
        <translation>Піти вперед</translation>
    </message>
    <message>
        <source>Discover item</source>
        <translation>Переглянути </translation>
    </message>
    <message>
        <source>Reload items</source>
        <translation>Перезавантажити </translation>
    </message>
    <message>
        <source>Show discovery info</source>
        <translation>Показати оглядову інформацію </translation>
    </message>
    <message>
        <source>Add item to roster</source>
        <translation>Додати до ростеру</translation>
    </message>
    <message>
        <source>Show vCard</source>
        <translation>Показати візитівку</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <comment>Show vCard</comment>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Close discovery window</source>
        <translation>Закрити вікно оглядової інформації</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close discovery window</comment>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Category: %1; Type: %2</source>
        <translation>Категорія: %1; Тип: %2</translation>
    </message>
</context>
</TS>
